/*
 * sl_callback_functions.c
 *
 *  Created on: 15 abr. 2018
 *      Author: antonio
 */


#include <Queues/queuedebug.h>
#include <Queues/queueroverstatus.h>
#include <Queues/queuetelemetry.h>
#include <Queues/queuecommands.h>
#include <Queues/queuemode.h>

#include <Telemetry/telemetry.h>

#include <stdio.h>

/* TI-DRIVERS Header files */
#include <ti/drivers/net/wifi/simplelink.h>
#include <ti/drivers/net/wifi/source/protocol.h>

/* Common definitions */
#include <common_def.h>
#include <Tda/networkstatus.h>
#include <Tda/rovercommand.h>
#include <Tda/roverdirection.h>
#include <Tda/rovermode.h>
#include "network_configuration.h"


static t_RoverCommand roverCommand;

static t_Mode xRoverMode;

/*
 * SimpleLink Callback functions to manage network events
 */

/* Header of additional functions */

int32_t NetappHttpGetRequest(SlNetAppRequest_t *pNetAppRequest,SlNetAppResponse_t *pNetAppResponse);


/******************************************************************************
//
//! \brief The Function Handles WLAN Events
//!
//! \param[in]  pWlanEvent - Pointer to WLAN Event Info
//!
//! \return None
//!
//!*****************************************************************************
 *
 */
void SimpleLinkWlanEventHandler(SlWlanEvent_t *pWlanEvent)
{

    char log_message[MAX_STRING];

    if(!pWlanEvent)
     {
         return;
     }

     switch(pWlanEvent->Id)
     {
     case SL_WLAN_EVENT_CONNECT:

         xQueueDebugSend("[WLAN EVENT] SL_WLAN_EVENT_CONNECT EVENT");

         /* Save SSID name for information */
         strcpy(log_message,"[WLAN EVENT] SSID NAME: ");
         strcat(log_message,(const char *)pWlanEvent->Data.Connect.SsidName);

         xQueueDebugSend(log_message);

         sprintf(log_message,"[WLAN EVENT] BSSID %02x:%02x:%02x:%02x:%02x:%02x",pWlanEvent->Data.Connect.Bssid[0],
                 pWlanEvent->Data.Connect.Bssid[1],
                 pWlanEvent->Data.Connect.Bssid[2],
                 pWlanEvent->Data.Connect.Bssid[3],
                 pWlanEvent->Data.Connect.Bssid[4],
                 pWlanEvent->Data.Connect.Bssid[5]);

         /* Save SSID name for information */
         xQueueDebugSend(log_message);

         /* Update network status */

         vNetStatusSet(WLAN_CONNECTED);

         /* Initialize structure for keeping network instructions */

         roverCommandInit(&roverCommand);
         vRoverModeInit(&xRoverMode);

         break;

     case SL_WLAN_EVENT_DISCONNECT:

         strcpy(log_message,"[WLAN EVENT] SL_WLAN_EVENT_DISCONNECT EVENT ");
         xQueueDebugSend(log_message);

         /* Update network status */
         vNetStatusSet(WLAN_DISCONNECTED);

         break;

     case SL_WLAN_EVENT_STA_ADDED:

         /* Only informational not in use */
         xQueueDebugSend("[WLAN EVENT]  SL_WLAN_EVENT_STA_ADDED EVENT");
         break;

     case SL_WLAN_EVENT_STA_REMOVED:

         /* Only informational not in use */
         xQueueDebugSend("[WLAN EVENT] SL_WLAN_EVENT_STA_REMOVED EVENT");
         break;

     case SL_WLAN_EVENT_RXFILTER:

         /* Only informational not in use */
         xQueueDebugSend("[WLAN EVENT] SL_WLAN_EVENT_STA_RXFILTER EVENT");
          /*
          *     User can write he's / her's rx filter match handler here.
          *     Be advised, you can use the 'triggred_filter' structure info to determine which filter
          *     has received a match. (Bit X is set if user action id X was passed to a filter that matched a packet.)
          */
         break;

     default:
         /* Only informational not in use */
         xQueueDebugSend("[WLAN EVENT] Unexpected event");
     }
}


//*****************************************************************************
//
//! \brief The Function Handles the Fatal errors
//!
//! \param[in]  slFatalErrorEvent - Pointer to Fatal Error Event info
//!
//! \return None
//!
//*****************************************************************************
void SimpleLinkFatalErrorEventHandler(SlDeviceFatal_t *slFatalErrorEvent)
{
    xQueueDebugSend("[WLAN EVENT] SimpleLinkFatalErrorEventHandler CallBack Function.");
    /* Update network status */
    vNetStatusSet(NET_ERROR);
}


//*****************************************************************************
//
//! \brief This function handles network events such as IP acquisition, IP
//!           leased, IP released etc.
//!
//! \param[in]  pNetAppEvent - Pointer to NetApp Event Info
//!
//! \return None
//!
//*****************************************************************************
void SimpleLinkNetAppEventHandler(SlNetAppEvent_t *pNetAppEvent)
{

    int32_t ip;
    int32_t gw;
    int32_t dns;

    char log_message[MAX_STRING];

    if(!pNetAppEvent)
     {
         return;
     }

     switch(pNetAppEvent->Id)
     {
     case SL_NETAPP_EVENT_IPV4_ACQUIRED:

         xQueueDebugSend("[NETAPP EVENT] IPv4 Acquired");

         ip=pNetAppEvent->Data.IpAcquiredV4.Ip;
         gw=pNetAppEvent->Data.IpAcquiredV4.Gateway;
         dns=pNetAppEvent->Data.IpAcquiredV4.Dns;

         /* collect and show ip configuration information */
         sprintf(log_message,"[NETAPP EVENT] IP Address: %d.%d.%d.%d",
                                     (const char*) SL_IPV4_BYTE(ip, 3),
                                     (const char*) SL_IPV4_BYTE(ip, 2),
                                     (const char*) SL_IPV4_BYTE(ip, 1),
                                     (const char*) SL_IPV4_BYTE(ip, 0));
         xQueueDebugSend(log_message);

         sprintf(log_message,"[NETAPP EVENT] GW Address: %d.%d.%d.%d",
                                     (const char*) SL_IPV4_BYTE(gw, 3),
                                     (const char*) SL_IPV4_BYTE(gw, 2),
                                     (const char*) SL_IPV4_BYTE(gw, 1),
                                     (const char*) SL_IPV4_BYTE(gw, 0));
         xQueueDebugSend(log_message);

         sprintf(log_message,"[NETAPP EVENT] DNS Address: %d.%d.%d.%d",
                                     (const char*) SL_IPV4_BYTE(dns, 3),
                                     (const char*) SL_IPV4_BYTE(dns, 2),
                                     (const char*) SL_IPV4_BYTE(dns, 1),
                                     (const char*) SL_IPV4_BYTE(dns, 0));
         xQueueDebugSend(log_message);

         /* Update network status */
         vNetStatusSet(IP_ACQUIRED);

         break;

     case SL_NETAPP_EVENT_DHCPV4_LEASED:

         /* Only informational not in use */
         xQueueDebugSend("[NETAPP EVENT] DHCPv4 Leased");
         break;

     case SL_NETAPP_EVENT_DHCPV4_RELEASED:

         /* Only informational not in use */
         xQueueDebugSend("[NETAPP EVENT] DHCPv4 Released");

         break;

     default:
         /* Only informational not in use */
         xQueueDebugSend("[NETAPP EVENT] Unexpected event");

     }

}

//*****************************************************************************
//
//! \brief This function handles HTTP server events
//!         This function capture HTTP TOKENS from NP
//!         HTTP GET TOKEN contains request for telemetry data
//!         HTTP POST TOKEN contain commands for the rover
//!
//! \param[in]  pServerEvent    - Contains the relevant event information
//! \param[in]  pServerResponse - Should be filled by the user with the
//!                               relevant response information
//!
//! \return None
//!
//****************************************************************************
void SimpleLinkHttpServerEventHandler(    SlNetAppHttpServerEvent_t *pHttpEvent,
                                          SlNetAppHttpServerResponse_t *
                                          pHttpResponse)
{

    char token_name[MAX_STRING];
    char token_value[MAX_STRING];

    t_RoverStatus status;
    t_Telemetry telemetry;

    /* Select http event type */
    switch (pHttpEvent->Event){

        /* Process GET HOST TOKEN (Telemetry data request)*/
       case SL_NETAPP_EVENT_HTTP_TOKEN_GET:

           //pHttpResponse->Response = SL_NETAPP_HTTP_RESPONSE_200_OK;
           /* Get token name */
           snprintf(token_name, (pHttpEvent->EventData.HttpTokenName.Len)+1,"%s",pHttpEvent->EventData.HttpTokenName.pData);

           /* Get rover and telemetry status */
           xQueueRoverStatusGetFromISR(&status);
           xQueueTelemetryGetFromISR(&telemetry);

           /* Fill HTTP  answer with telemetry parameters */

           /* Asking for rover direction */
            if (strcmp(token_name,HTTP_TOKEN_GET_DIR)==00){

                pHttpResponse->ResponseData.TokenValue.Len = roverStatusGetDirectionStr(status,(char *)pHttpResponse->ResponseData.TokenValue.pData);

            }

            /* Asking for rover speed */
            else if (strcmp(token_name,HTTP_TOKEN_GET_SPE)==0){

                pHttpResponse->ResponseData.TokenValue.Len = roverStatusGetSpeedStr(status,(char *)pHttpResponse->ResponseData.TokenValue.pData);

            }

            /* Asking for rover light sensor information */
            else if (strcmp(token_name,HTTP_TOKEN_GET_LIG)==0){
                pHttpResponse->ResponseData.TokenValue.Len =  telemetryGetLuxStr(telemetry, (char *)pHttpResponse->ResponseData.TokenValue.pData);

           }

            /* Asking for rover humidity sensor information */
            else if (strcmp(token_name,HTTP_TOKEN_GET_HUM)==0){
                pHttpResponse->ResponseData.TokenValue.Len =  telemetryGetBme280HumStr(telemetry, (char *)pHttpResponse->ResponseData.TokenValue.pData);

            }

            /* Asking for rover pressure sensor information */
            else if (strcmp(token_name,HTTP_TOKEN_GET_PRE)==0){
                pHttpResponse->ResponseData.TokenValue.Len =  telemetryGetBme280PreStr(telemetry, (char *)pHttpResponse->ResponseData.TokenValue.pData);

            }

            /* Asking for rover temperature sensor information */
            else if (strcmp(token_name,HTTP_TOKEN_GET_TEM)==0){
                pHttpResponse->ResponseData.TokenValue.Len =  telemetryGetBme280TemStr(telemetry, (char *)pHttpResponse->ResponseData.TokenValue.pData);
            }

            break;

        /* Process POST HOST TOKEN - Rover commands */
        case SL_NETAPP_EVENT_HTTP_TOKEN_POST:
            snprintf(token_name, (pHttpEvent->EventData.HttpPostData.TokenName.Len)+1 ,"%s",pHttpEvent->EventData.HttpPostData.TokenName.pData);

            if (pHttpEvent->Event==SL_NETAPP_EVENT_HTTP_TOKEN_POST){

                /* Save token value */
               snprintf(token_value, (pHttpEvent->EventData.HttpPostData.TokenValue.Len)+1 ,"%s",pHttpEvent->EventData.HttpPostData.TokenValue.pData);

               /* It checks http token received via POST request */
               if (strcmp(token_name,HTTP_TOKEN_SPEED) == 0){

                   /* Format data and fill command structure with speed */

                   roverCommandSetSpeed(atoi(token_value),&roverCommand);

               }
               else if (strcmp(token_name,HTTP_TOKEN_TIME) == 0){

                   /* Format data and fill command structure with command time */
                   roverCommandSetTime(atoi(token_value), &roverCommand);

                    }

               else if (strcmp(token_name,HTTP_TOKEN_DIR) == 0){

                   /* Format data and fill command structure with command direction */
                   roverDirectionSetDirectionFromString(&roverCommand.direction, token_value);

               }
               else if (strcmp(token_name,HTTP_TOKEN_MODE) == 0){

                   /* Format data and fill command structure with a rover mode */
                   vRoverModeSetMode(atoi(token_value), &xRoverMode);

               }
               else if (strcmp(token_name,HTTP_TOKEN_LOOPS) == 0){

                   /* Format data and fill command structure with a loops to execute */
                   vRoverModeSetLoop(atoi(token_value), &xRoverMode);

                   }
               }
               else {
                   xQueueDebugSend("[HTTPSERVER EVENT] Unknown token");
               }

               /* If rover command structure is ready then send it to the queue */
               if (roverCommandIsReady(roverCommand) == pdTRUE){

                   xQueueCommandsSendFromISR(&roverCommand);
                   xQueueDebugSend("[HTTPSERVER EVENT] Sending command");
                   /* Reset command structure */
                   roverCommandInit(&roverCommand);

               }

               /* If rover mode structure is ready then send it to queue */
               if ( ucRoverModeReady(xRoverMode) == pdTRUE ){
                   vQueueModeSet(&xRoverMode);
                   xQueueDebugSend("[HTTPSERVER EVENT] Setting mode");
                   /* Reset mode structure */
                   vRoverModeInit(&xRoverMode);
               break;
            }
    /* Fill response code */
    pHttpResponse->Response = SL_NETAPP_HTTP_RESPONSE_200_OK;
    }
}

//*****************************************************************************
//
//! \brief This function handles General Events
//!
//! \param[in]  pDevEvent - Pointer to General Event Info
//!
//! \return None
//!
//*****************************************************************************
void SimpleLinkGeneralEventHandler(SlDeviceEvent_t *pDevEvent)
{
    xQueueDebugSend("[NETAPP EVENT] SimpleLink General Event Handler CallBack Function");


}

//*****************************************************************************
//
//! \brief This function handles socket events indication
//!
//! \param[in]  pSock - Pointer to Socket Event Info
//!
//! \return None
//!
//*****************************************************************************
void SimpleLinkSockEventHandler(SlSockEvent_t *pSock)
{
    xQueueDebugSend("\r\nSimpleLinkSockEventHandler CallBack Function\r\n");

}


//*****************************************************************************
//
//! \brief This function handles Net App request, for this project, only user for learning
//!
//! \param[in]  pNetAppRequest, received request
//!             pNetAppResponse, to be filled
//! \return None
//!
//*****************************************************************************
void SimpleLinkNetAppRequestEventHandler(SlNetAppRequest_t *pNetAppRequest,
                                         SlNetAppResponse_t *pNetAppResponse)
{
    char log_message[MAX_STRING];

    xQueueDebugSend("[NETAPP EVENT] SimpleLink NetApp Request Event Handler");

    switch (pNetAppRequest->AppId){
            case SL_NETAPP_HTTP_SERVER_ID:
                switch(pNetAppRequest->Type)

                case SL_NETAPP_REQUEST_HTTP_GET:

                    sprintf(log_message,"[NETAPP EVENT] HTTP GET REQUEST. TYPE: %d",pNetAppRequest->Type);
                    xQueueDebugSend(log_message);
                    break;

                case SL_NETAPP_REQUEST_HTTP_POST:

                    sprintf(log_message,"[NETAPP EVENT] HTTP POST REQUEST. TYPE: %d",pNetAppRequest->Type);
                    xQueueDebugSend(log_message);
                    break;

                default:

                    sprintf(log_message,"[NETAPP EVENT] HTTP UNKNOW REQUEST. TYPE: %d",pNetAppRequest->AppId);
                    xQueueDebugSend(log_message);
                }


}

void SimpleLinkNetAppRequestMemFreeEventHandler(uint8_t *buffer)
{
    xQueueDebugSend("\r\nSimpleLinkNetAppRequestMemFreeEventHandler CallBack Function\r\n");
}

/* Not in use */
/* Only for debug */

int32_t NetappHttpGetRequest(SlNetAppRequest_t *pNetAppRequest,SlNetAppResponse_t *pNetAppResponse){


    xQueueDebugSend("[NETAPP EVENT] SimpleLink NetApp HTTP Get Request");

    return (0);
}

