/*
 * udpclient.c
 *
 *  Created on: 22 abr. 2018
 *      Author: antonio
 */

#include "udpclient.h"
#include "network_configuration.h"

/* TI Drivers */
#include <ti/drivers/net/wifi/simplelink.h>

#include <Queues/queuedebug.h>

#include "common_def.h"



//**********************************************************************
//!
//! \brief  This routine send data to telemetry server using UDP sockets
//!         This routine send a chunk of data to the UDP server
//!         defined by TELEMETRY_SERVER_IP
//!
//! \param  string, pointer to data to send
//!
//! \return none
//!
//********************************************************************

void vUDPClient(char *string){

    _i16 socketDescriptor;
    SlSockAddrIn_t Addr;
    int8_t ucStatus;

    /* Open the socket */
    socketDescriptor = sl_Socket(SL_AF_INET, SL_SOCK_DGRAM, 0);

    if(  socketDescriptor < 0 )
    {
    /* Error opening the socket */
        xQueueDebugSend("[NET TASK] UDP Client - error opening socket");
        return;
    }

    /* Fill structure */
    Addr.sin_family = SL_AF_INET;
    Addr.sin_port = sl_Htons(TELEMETRY_SERVER_PORT);
    Addr.sin_addr.s_addr = sl_Htonl(SL_IPV4_VAL(TELEMETRY_SERVER_IP_A,
                                                TELEMETRY_SERVER_IP_B,
                                                TELEMETRY_SERVER_IP_C,
                                                TELEMETRY_SERVER_IP_D));

    /* Send data */
    ucStatus = sl_SendTo(socketDescriptor, string, strlen(string), 0, (SlSockAddr_t*)&Addr,sizeof(SlSockAddr_t));

    if( strlen(string) != ucStatus )
    {
        xQueueDebugSend("[NET TASK] UDP Client - Error sending UDP traffic");
    }

    /* Close the socket */
    ucStatus = sl_Close(socketDescriptor);
    if( ucStatus )
    {
        xQueueDebugSend("[NET TASK] UDP Client - Error closing socket");
    }

};
