/*
 * queueCommands.c
 *
 *  Created on: 27 may. 2018
 *      Author: antonio
 */


#include "queuecommands.h"

/* FreeRTOS header files */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"


/* Queue for transmit commands */
static QueueHandle_t xQueueCommand;

/******************************************************************************
//
//! \brief The Function inialize the queue for rover commands
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/

void vQueueCommandsInit(void){

    /* Queue for 10 commands */
    xQueueCommand = xQueueCreate(10, sizeof(t_RoverCommand) );
    configASSERT(xQueueCommand);
}

/******************************************************************************
//
//! \brief  Post an command to the back of a queue
//!
//! \param  command, pointer to the command that is to be placed on the queue
//!
//! \return uint8_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueCommandsSend(t_RoverCommand *command){

    return xQueueSendToBack(xQueueCommand,command,0);
}

/******************************************************************************
//
//! \brief  Post an command to the back of a queue (from ISR)
//!
//! \param  command, pointer to the command that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
//!*****************************************************************************
*/
BaseType_t xQueueCommandsSendFromISR(t_RoverCommand *command){
    return xQueueSendToBackFromISR(xQueueCommand,command, NULL);
}

/******************************************************************************
//
//! \brief  Receive an command from a queue
//!
//! \param  t_RoverCommand, pointer to the command structure
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueCommandsReceive(t_RoverCommand *command){

    return xQueueReceive( xQueueCommand,  command, pdMS_TO_TICKS( 10 ) );
}

/******************************************************************************
//
//! \brief Clear the command queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/
void vQueueCommandReset(void){
         xQueueReset( xQueueCommand );
}
