/*
 * queueCommands.h
 *
 *  This queue allows send rover commands between tasks
 *
 *  Created on: 27 may. 2018
 *      Author: antonio
 */

#ifndef QUEUES_QUEUECOMMANDS_H_
#define QUEUES_QUEUECOMMANDS_H_

#include "../Tda/rovercommand.h"

/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/

void vQueueCommandsInit(void);

/******************************************************************************
//
//! \brief  Post an command to the back of a queue
//!
//! \param  command, pointer to the command that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueCommandsSend(t_RoverCommand *command);

/******************************************************************************
//
//! \brief  Post an command to the back of a queue (from ISR)
//!
//! \param  command, pointer to the command that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
//!*****************************************************************************
*/
BaseType_t xQueueCommandsSendFromISR(t_RoverCommand *command);

/******************************************************************************
//
//! \brief  Receive an command from a queue
//!
//! \param  t_RoverCommand, pointer to the command structure
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueCommandsReceive(t_RoverCommand *command);

/******************************************************************************
//
//! \brief Clear the command queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/

void vQueueCommandReset(void);

#endif /* QUEUES_QUEUECOMMANDS_H_ */
