/*
 * queuedebug.c
 *
 *  Created on: 14 abr. 2018
 *      Author: antonio
 */



#include <Queues/queuedebug.h>

/* FreeRTOS header files */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"


#include <stdint.h>

#include <common_def.h>

static QueueHandle_t xQueueDEBUG; // Queue for transmit log messages

/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/
void vQueueDebugInit(){
    /* Queue for debug messages */
    xQueueDEBUG = xQueueCreate(30, sizeof(char[MAX_STRING]) );
    configASSERT(xQueueDEBUG);
};

/******************************************************************************
//
//! \brief  Post a string to the back of a queue
//!
//! \param  message, pointer to the string that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueDebugSend(char message[MAX_STRING]){
    return xQueueSendToBack(xQueueDEBUG,message,0);

}

/******************************************************************************
//
//! \brief  Post a string to the back of a queue (from ISR)
//!
//! \param  message, pointer to the string that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueDebugSendFromISR(char message[MAX_STRING]){
    return xQueueSendToBackFromISR(xQueueDEBUG,message,0);

}

/******************************************************************************
//
//! \brief  Receive a string from a queue
//!
//! \param  message, pointer to the string
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueDebugReceive(char message[MAX_STRING]){
    return xQueueReceive( xQueueDEBUG,  message, pdMS_TO_TICKS( 10 ) );
    }


