/*
 * queuedebug.h
 *
 *  A queue to send data (strings) for debug purpose to the UART port
 *
 *  Created on: 14 abr. 2018
 *      Author: antonio
 */

#ifndef ROVERDEBUG_QUEUEDEBUG_H_
#define ROVERDEBUG_QUEUEDEBUG_H_

/* FreeRTOS header files */
#include "FreeRTOS.h"
#include <stdint.h>


/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/
void vQueueDebugInit();

/******************************************************************************
//
//! \brief  Post a string to the back of a queue
//!
//! \param  message, pointer to the string that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueDebugSend(char *message);

/******************************************************************************
//
//! \brief  Post a string to the back of a queue (from ISR)
//!
//! \param  message, pointer to the string that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueDebugSendFromISR(char *message);

/******************************************************************************
//
//! \brief  Receive a string from a queue
//!
//! \param  message, pointer to the string
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueDebugReceive(char *message);


#endif /* ROVERDEBUG_QUEUEDEBUG_H_ */
