/*
 * queuemode.c
 *
 *  Created on: 3 jun. 2018
 *      Author: antonio
 */

#include "queuemode.h"

/* FreeRTOS header files */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"

static QueueHandle_t xQueueMode; // Queue for set rover mode

/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
 */
void vQueueModeInit(){
    /* Queue for debug messages */
    xQueueMode = xQueueCreate(1, sizeof(t_Mode) );
    configASSERT(xQueueMode);
}

/******************************************************************************
//
//! \brief  Post an rover mode in the queue
//!
//! \param  mode, pointer to the rover mode structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
void vQueueModeSet(t_Mode  *mode){
    uint8_t retc;
    retc =xQueueOverwrite(xQueueMode, mode);
    configASSERT(retc);
}

/******************************************************************************
//
//! \brief  Post an rover mode in the queue (from ISR)
//!
//! \param  mode, pointer to the rover mode structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
void vQueueModeSetFromISR(t_Mode *mode){
    uint8_t retc;
    retc =xQueueOverwriteFromISR(xQueueMode, mode, NULL);
    configASSERT(retc);
}

/******************************************************************************
//
//! \brief  Get rover mode from a queue
//!
//! \param  t_RoverCommand, pointer to the rover move structure
//!          into which the read item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
void vQueueModeGet(t_Mode *mode){
    uint8_t retc;
    retc = xQueuePeek(xQueueMode, mode, 0 );
    configASSERT(retc);
}

/******************************************************************************
//
//! \brief  Get rover mode from a queue (From ISR)
//!
//! \param  t_RoverCommand, pointer to the rover move structure
//!          into which the read item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
void vQueueModeGetFromISR(t_Mode *mode){
    uint8_t retc;
    retc = xQueuePeekFromISR(xQueueMode, mode);
    configASSERT(retc);
}
