/*
 * queueMode.h
 *
 *  This queue keeps rover working mode
 *
 *  Created on: 3 jun. 2018
 *      Author: antonio
 */

#ifndef QUEUES_QUEUEMODE_C_
#define QUEUES_QUEUEMODE_C_

#include "../Tda/rovermode.h"

/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
 */
void vQueueModeInit();

/******************************************************************************
//
//! \brief  Post an rover mode in the queue
//!
//! \param  mode, pointer to the rover mode structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
void  vQueueModeSet(t_Mode  *mode);

/******************************************************************************
//
//! \brief  Post an rover mode in the queue (from ISR)
//!
//! \param  mode, pointer to the rover mode structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
void  vQueueModeSetFromISR(t_Mode *mode);

/******************************************************************************
//
//! \brief  Get rover mode from a queue
//!
//! \param  t_RoverCommand, pointer to the rover move structure
//!          into which the read item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
void vQueueModeGet(t_Mode *mode);

/******************************************************************************
//
//! \brief  Get rover mode from a queue (From ISR)
//!
//! \param  t_RoverCommand, pointer to the rover move structure
//!          into which the read item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
void vQueueModeGetFromISR(t_Mode *mode);


#endif /* QUEUES_QUEUEMODE_C_ */
