/*
 * queueroverstatus.c
 *
 *  Created on: 2 may. 2018
 *      Author: antonio
 */

#include "queueroverstatus.h"

static QueueHandle_t xQueueRoverStatus;


/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/
void vQueueRoverStatusInit(){

    xQueueRoverStatus = xQueueCreate(1, sizeof(t_RoverStatus) );
    configASSERT(xQueueRoverStatus);

}


/******************************************************************************
//
//! \brief  Set the rover status in the queue
//!
//! \param  status, pointer to a rover status that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusSet(t_RoverStatus *status){

    return xQueueOverwrite(xQueueRoverStatus, status );

}

/******************************************************************************
//
//! \brief  Set the rover status in the queue (from ISR)
//!
//! \param  status, pointer to a rover status that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusSetFromISR(t_RoverStatus *status){
    return 0;
}

/******************************************************************************
//
//! \brief  Get rover status from a queue
//!
//! \param  status, pointer to a rover status structure
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusGet(t_RoverStatus *status){
    return xQueuePeek(xQueueRoverStatus, status, 0 );
}

/******************************************************************************
//
//! \brief  Get rover status from a queue (from ISR)
//!
//! \param  status, pointer to a rover status structure
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusGetFromISR(t_RoverStatus *status){
    return xQueuePeekFromISR(xQueueRoverStatus, status);
}

/******************************************************************************
//
//! \brief  Get handle to the queue
//!
//! \param  none
//!
//! \return none
//!
//!*****************************************************************************
*/
QueueHandle_t queueRoverStatusGetQueue(void);

