/*
 * queuedirection.h
 *
 *
 * This queues informs about rover status
 * This queues implements a mailbox where task can read the rover status
 *
 *  Created on: 26 abr. 2018
 *      Author: antonio
 */

#ifndef QUEUES_QUEUEROVERSTATUS_H_
#define QUEUES_QUEUEROVERSTATUS_H_

/* FreeRTOS header files */
#include "../Rover/roverstatus.h"
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "timers.h"


/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/
void vQueueRoverStatusInit();

/******************************************************************************
//
//! \brief  Set the rover status in the queue
//!
//! \param  status, pointer to a rover status that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusSet(t_RoverStatus *status);

/******************************************************************************
//
//! \brief  Set the rover status in the queue (from ISR)
//!
//! \param  status, pointer to a rover status that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusSetFromISR(t_RoverStatus *status);

/******************************************************************************
//
//! \brief  Get rover status from a queue
//!
//! \param  status, pointer to a rover status structure
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusGet(t_RoverStatus *status);

/******************************************************************************
//
//! \brief  Get rover status from a queue (from ISR)
//!
//! \param  status, pointer to a rover status structure
//!          into which the received item will be copied.
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueRoverStatusGetFromISR(t_RoverStatus *status);

/******************************************************************************
//
//! \brief  Get handle to the queue
//!
//! \param  none
//!
//! \return none
//!
//!*****************************************************************************
*/
QueueHandle_t xQueueRoverStatusGetQueue(void);


#endif /* QUEUES_QUEUEROVERSTATUS_H_ */
