/*
 * queuetelemtry.c
 *
 *  This queue (Mailbox) keeps last telemetry data
 *
 *  Created on: 14 abr. 2018
 *      Author: antonio
 */



#include <Queues/queuetelemetry.h>
#include <Queues/queuedebug.h>

#include <Telemetry/telemetry.h>

static QueueHandle_t xQueueTELEMETRY; // Queue for transmit log messages

/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/
void vQueueTelemetryInit(){
    /* Queue for debug messages */
    xQueueTELEMETRY = xQueueCreate(1, sizeof(t_Telemetry) );
    configASSERT(xQueueTELEMETRY);
};

/******************************************************************************
//
//! \brief  Set a telemetry in the queue
//!
//! \param  telemetry, pointer to the telemetry structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueTelemetrySet(t_Telemetry *telemetry){
    return xQueueOverwrite(xQueueTELEMETRY, telemetry);
};

/******************************************************************************
//
//! \brief  Get a telemetry data from a queue
//!
//! \param  telemetry, pointer to the telemetry structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueTelemetryGet(t_Telemetry *telemetry){
    return xQueuePeek(xQueueTELEMETRY, telemetry, 0 );
    };

/******************************************************************************
//
//! \brief  Get a telemetry data  from a queue (from ISR)
//!
//! \param  telemetry, pointer to the telemetry structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueTelemetryGetFromISR(t_Telemetry *telemetry){
    return xQueuePeekFromISR(xQueueTELEMETRY, telemetry);
    };
