/*
 * queuetelemtry.h
 *
 * *
 *  This queue (Mailbox) keeps last telemetry data
 *
 *
 *  Created on: 14 abr. 2018
 *      Author: antonio
 */

#ifndef QUEUE_QUEUETELEMTRY_H_
#define QUEUE_QUEUETELEMTRY_H_

/* FreeRTOS header files */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "timers.h"

#include <Telemetry/telemetry.h>

/******************************************************************************
//
//! \brief The Function initialize the queue
//!
//! \param  none,
//!
//! \return none,
//!
//!*****************************************************************************
*/
void vQueueTelemetryInit();

/******************************************************************************
//
//! \brief  Set a telemetry in the queue
//!
//! \param  telemetry, pointer to the telemetry structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if the item was successfully posted, otherwise errQUEUE_FULL
//!
//!*****************************************************************************
*/
BaseType_t xQueueTelemetrySet(t_Telemetry *telemetry);

/******************************************************************************
//
//! \brief  Get a telemetry data from a queue
//!
//! \param  telemetry, pointer to the telemetry structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueTelemetryGet(t_Telemetry *telemetry);

/******************************************************************************
//
//! \brief  Get a telemetry data  from a queue (from ISR)
//!
//! \param  telemetry, pointer to the telemetry structure that is to be placed on the queue
//!
//! \return BaseType_t, pdTRUE if an item was successfully received from the queue,
//!                     otherwise pdFALSE
//!
//!*****************************************************************************
*/
BaseType_t xQueueTelemetryGetFromISR(t_Telemetry *telemetry);


#endif /* QUEUE_QUEUECOMMAND_H_ */
