/*
 * l298n.c
 *
 *  Created on: 14 abr. 2018
 *      Author: antonio
 */



#include "l298n.h"

#include "FreeRTOS.h"
#include "task.h"

#include <stdio.h>
#include <string.h>

/* Driver Header files */
#include <ti/drivers/GPIO.h>
#include <ti/drivers/PWM.h>


#include "common_def.h"
#include <Queues/queuedebug.h>




/* Board Header file */
#include <Board.h>
#include <Rover/roverstatus.h>


/* PWM Handles*/

    PWM_Handle pwm1 = NULL;
    PWM_Handle pwm2 = NULL;

/******************************************************************************
//
//! \brief The Function initialize PWM
//!
//!        This routing set PWM period, initial and start it
//!
//! \return None
//!
//!*****************************************************************************
*/
void l298nInitPWM(){

        uint16_t   pwmPeriod = 100;

        /* PWM params */

        PWM_Params params;

        xQueueDebugSend("[L298N] PWM Init");

        PWM_init();

        PWM_Params_init(&params);

        /* Define PWM parameters */
        params.periodUnits = PWM_PERIOD_HZ;
        params.dutyValue = 0;
        params.dutyUnits = PWM_DUTY_FRACTION;
        params.periodValue = pwmPeriod;

        /* Set PWM parameters in pwm0 instance */
        pwm1 = PWM_open(Board_PWM0, &params);
        configASSERT(pwm1);

        /* Set PWM parameters in pwm1 instance */
        pwm2 = PWM_open(Board_PWM1, &params);
        configASSERT(pwm2);

        /* Start PWM interfaces */
        PWM_start(pwm1);
        PWM_start(pwm2);

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!
//!         GPIO P4_5 Output connected to I1
//!         GPIO P4.7 Output connected to I2
//!         GPIO P5.4 Output connected to I3
//!         GPIO P5.5 Output connected to I4
//!
//! \return None
//!
//!**********************************************************************************
 */
void l298nConfigurePins()
{
    // It is not necessary because this configuration is done in board configuration files
    // and set at board initialization
    // Only informative
    GPIO_setConfig(Board_GPIO_I1, GPIO_CFG_OUT_STD | GPIO_CFG_OUT_STR_MED | GPIO_CFG_OUT_LOW);
    GPIO_setConfig(Board_GPIO_I2, GPIO_CFG_OUT_STD | GPIO_CFG_OUT_STR_MED | GPIO_CFG_OUT_LOW);
    GPIO_setConfig(Board_GPIO_I3, GPIO_CFG_OUT_STD | GPIO_CFG_OUT_STR_MED | GPIO_CFG_OUT_LOW);
    GPIO_setConfig(Board_GPIO_I4, GPIO_CFG_OUT_STD | GPIO_CFG_OUT_STR_MED | GPIO_CFG_OUT_LOW);

};

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         only for clarify how connection to L298N works, all configurations
//!         are done at board initialization files
//!         (Board.h, MSP_EXP432P401R.c y MSP_EXP432P401R.h)
//!
//! \return None
//!
//!**********************************************************************************
 */
void l298nInit(void){
    xQueueDebugSend("[L298N] L298N Init");

    /* Initalize MSP432 to L298N ports */
    l298nConfigurePins();
    l298nInitPWM();
    l298nStop();

};


/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to stop the vehicle
//!
//! \return None
//!
//!**********************************************************************************
 */
void l298nStop(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_LOW);
    xQueueDebugSend("[ROVER TASK] STOPPED");


}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to move the vehicle backward
//!
//! \return None
//!
//!**********************************************************************************
*/
void l298nBackward(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_LOW);

    xQueueDebugSend("[ROVER TASK] MOVING BACKWARD");

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to move the vehicle forward
//!
//! \return None
//!
//!**********************************************************************************
 */
void l298nForward(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_HIGH);

    xQueueDebugSend("[ROVER TASK] MOVING FORWARD");

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to move the vehicle to the right
//!
//! \return None
//!
//!**********************************************************************************
 */
void l298nForwardRight(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_HIGH);

    xQueueDebugSend("[ROVER TASK] MOVING RIGHT (FORWARD)");

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to rotate to the right side
//!
//! \return None
//!
//!**********************************************************************************
 */
void l298nRight(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_HIGH);

    xQueueDebugSend("[ROVER TASK] ROTATING RIGHT");

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to move the vehicle to the left
//!
//! \return None
//!
//!**********************************************************************************
 */
void l298nForwardLeft(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_LOW);

    xQueueDebugSend("[ROVER TASK] MOVING LEFT (FORWARD)");

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to move the vehicle to the left (but going backward).
//!
//! \return None
//!
//!**********************************************************************************
*/
void l298nBackwardLeft(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_LOW);

    xQueueDebugSend("[ROVER TASK] MOVING LEFT (BACKWARD)");

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to move the vehicle to the right (but going backward).
//!
//! \return None
//!
//!**********************************************************************************
 */

void l298nBackwardRight(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_LOW);

    xQueueDebugSend("[ROVER TASK] MOVING RIGHT (BACKWARD)");

}

/************************************************************************************
//!
//! \brief  The routine configure GPIO ports connected to L298N pins (I1, I2, I3, I4)
//!         to move the vehicle to the left (but going backward).
//!
//! \return None
//!
//!**********************************************************************************
*/
void l298nLeft(void){

    GPIO_write(Board_GPIO_I1, Board_GPIO_PIN_LOW);
    GPIO_write(Board_GPIO_I2, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I3, Board_GPIO_PIN_HIGH);
    GPIO_write(Board_GPIO_I4, Board_GPIO_PIN_LOW);

    xQueueDebugSend("[ROVER TASK] ROTATING LEFT");

}

/************************************************************************************
//!
//! \brief  The routine configure PWM ports to change vehicle speed
//!
//! \param  speed, a value between 1 and 10 to adjust PWM duty cycle
//!         10 is the maximum speed and 0 the minimum speed
//!
//! \return None
//!
//!**********************************************************************************
*/
void l298nSetSpeed(uint8_t speed){

    /* Check valid speed values */
    if (speed > 10){
        PWM_setDuty(pwm1, PWM_DUTY_FRACTION_MAX);
        PWM_setDuty(pwm2, PWM_DUTY_FRACTION_MAX);
    }
    else if (speed < 1){
        PWM_setDuty(pwm1, PWM_DUTY_FRACTION_MAX*0.1);
        PWM_setDuty(pwm2, PWM_DUTY_FRACTION_MAX*0.1);
    }
    /* Configure speed (10 sections) */
    else{

        xQueueDebugSend("[ROVER TASK] SPEED CHANGE");
        PWM_setDuty(pwm1, PWM_DUTY_FRACTION_MAX*(speed*0.1));
        PWM_setDuty(pwm2, PWM_DUTY_FRACTION_MAX*(speed*0.1));
    }

};

/************************************************************************************
//!
//! \brief  The routine configure rover movement from a direction enum
//!
//! \param  direction, a value with direction to configure in the rover
//!
//! \return None
//!
//!**********************************************************************************
*/
void l298nSetDirection(direction_t direction){

    // Evaluate direction and configure outputs to implements it
    switch (direction){
         case FORWARD:
             l298nForward();
             break;

         case BACKWARD:
             l298nBackward();
             break;

         case RIGHT:
             l298nRight();
             break;

         case LEFT:
             l298nLeft();
             break;

         case STOP:
             l298nStop();
             break;

         case L_FORWARD:
             l298nForwardLeft();
             break;

         case R_FORWARD:
             l298nForwardRight();
             break;

         case L_BACKWARD:
             l298nBackwardLeft();
             break;

         case R_BACKWARD:
             l298nBackwardRight();
             break;

         case LOCK_FORWARD:
             xQueueDebugSend("[ROVER TASK] Obstacle in the road. Rover stopped");
             l298nStop();
             break;

         default:
             xQueueDebugSend("[ROVER TASK] Direction not valid");
    }
}





