/*
 * roverCommand.c
 *
 *  Created on: 27 may. 2018
 *      Author: antonio
 */

#include <Tda/rovercommand.h>


/******************************************************************************
//
//! \brief The Function initialize a rover command structure
//!
//! \parm   command, pointer to a rover command structure to initialize
//!
//! \return None
//!
//!*****************************************************************************
*/
void roverCommandInit(t_RoverCommand *command){
    command->direction = NO_SET;
    command->speed = -1;
    command->time = -1;
}

/******************************************************************************
//
//! \brief This routine check if command is ready (all fields are completed)
//!
//! \parm   command, pointer to a rover command structure to initialize
//!
//! \return uint8_t,    return NULL if command are not set
//!                     return 1 if structure is ready for send
//!
//!*****************************************************************************
*/
uint8_t roverCommandIsReady(t_RoverCommand command){

    // Check if all structure fields are ready
    if (command.direction == NO_SET || command.speed == -1 || command.time == -1){
        return pdFALSE;
    }
    else {
        return pdTRUE;
    }
}


/******************************************************************************
//
//! \brief The Function set speed in rover command structure
//!
//! \param  speed, speed to set
//! \param  command, pointer to a rover command structure
//!
//! \return None
//!
//!*****************************************************************************
*/
void roverCommandSetSpeed(uint8_t speed,t_RoverCommand *command){
    command->speed = speed;
}


/******************************************************************************
//
//! \brief The Function get speed in rover command structure
//!
//! \param   none
//!
//! \return  uint8_t , rover speed
//!
//!*****************************************************************************
*/
uint8_t roverCommandGetSpeed(t_RoverCommand command){
    return command.speed;
}




/******************************************************************************
//
//! \brief The Function set direction in rover command structure
//!
//! \param  direction, rover direction to set
//! \param  command,  a pointer to rover command structure
//!
//! \return uint8_t, speed
//!
//!*****************************************************************************
*/
void roverCommandSetDirection(direction_t direction, t_RoverCommand *command){
    command->direction = direction;
}

/******************************************************************************
//
//! \brief The Function get direction in rover command structure
//!
//! \param  command,  rover command structure
//!
//! \return direcction_t, direction from command structure
//!
//!*****************************************************************************
*/
direction_t roverCommandGetDirection(t_RoverCommand command){
    return command.direction;
}



/******************************************************************************
//
//! \brief The Function set command duration in seconds
//!
//! \param  time, time in seconds
//! \param  command, pointer to a rover command structure
//! \return none
//!
//!*****************************************************************************
*/
void roverCommandSetTime(uint8_t time,t_RoverCommand *command){
    command->time = time;
}


/******************************************************************************
//
//! \brief The Function to  command duration in seconds
//!
//! \param command,  a command structure
//!
//! \return uint8_t, time in seconds from command structure
//!
//!*****************************************************************************
*/
uint8_t roverCommandGetTime(t_RoverCommand command){
    return command.time;
}



