/*
 * roverCommand.h
 *
 *  Created on: 27 may. 2018
 *      Author: antonio
 */

#ifndef TDA_ROVERCOMMAND_H_
#define TDA_ROVERCOMMAND_H_

#include "../Tda/roverdirection.h"
#include "FreeRTOS.h"


/* ***************************************************************************
//! This structure represents a rover command
//!
//!    direction,   it is the rover direction (FORWARD, BACKWARD, RIGHT, LEFT,...)
//!
//!    speed,   it  is the rover speed (valid values are from 1 to 10).
//!
//!    time,    the command will be executing for this time in seconds
//!             if it is zero command will be valid till new command
//!             to the queue
//!
//!    loop mode, in this mode rover will execute commands in a loop
//!
//!     loops,      number of loops to execute
//!
//!****************************************************************************
 */

typedef struct {
                direction_t direction;
                int8_t  speed;
                int8_t  time;
} t_RoverCommand;



/******************************************************************************
//
//! \brief The Function initialize a rover command structure
//!
//! \parm   command, pointer to a rover command structure to initialize
//!
//! \return None
//!
//!*****************************************************************************
*/
void roverCommandInit(t_RoverCommand *command);

/******************************************************************************
//
//! \brief This routine check if command is ready (all fields have valid values)
//!
//! \parm   command, pointer to a rover command structure to initialize
//!
//! \return uint8_t,    return NULL if command are not set
//!                     return 1 if structure is ready for send
//!
//!*****************************************************************************
*/
uint8_t roverCommandIsReady(t_RoverCommand command);

/******************************************************************************
//
//! \brief The Function set speed in rover command structure
//!
//! \param  speed, speed to set
//! \param  command, pointer to a rover command structure
//!
//! \return None
//!
//!*****************************************************************************
*/
void roverCommandSetSpeed(uint8_t speed,t_RoverCommand *command);


/******************************************************************************
//
//! \brief The Function get speed in rover command structure
//!
//! \param   none
//!
//! \return  uint8_t , rover speed
//!
//!*****************************************************************************
*/
uint8_t roverCommandGetSpeed(t_RoverCommand command);




/******************************************************************************
//
//! \brief The Function set direction in rover command structure
//!
//! \param  direction, rover direction to set
//! \param  command,  a pointer to rover command structure
//!
//! \return uint8_t, speed
//!
//!*****************************************************************************
*/
void roverCommandSetDirection(direction_t direction, t_RoverCommand *command);



/******************************************************************************
//
//! \brief The Function get direction in rover command structure
//!
//! \param  command,  rover command structure
//!
//! \return direcction_t, direction from command structure
//!
//!*****************************************************************************
*/
direction_t roverCommandGetDirection(t_RoverCommand command);



/******************************************************************************
//
//! \brief The Function set command duration in seconds
//!
//! \param  time, time in seconds
//! \param  command, pointer to a rover command structure
//! \return none
//!
//!*****************************************************************************
*/
void roverCommandSetTime(uint8_t time,t_RoverCommand *command);


/******************************************************************************
//
//! \brief The Function to  command duration in seconds
//!
//! \param command,  a command structure
//!
//! \return uint8_t, time in seconds from command structure
//!
//!*****************************************************************************
*/
uint8_t roverCommandGetTime(t_RoverCommand command);


#endif /* TDA_ROVERCOMMAND_H_ */
