/*
 * roverdirection.h
 *
 *  Created on: 26 abr. 2018
 *      Author: antonio
 */

#ifndef TDA_ROVERDIRECTION_H_
#define TDA_ROVERDIRECTION_H_


/* ***************************************************************************
//! This structure represents all rover valid movements:
//!     FORWARD,    MOVE FORWARD
//!     BACKWARD,   MOVE BACKWARD
//!     LEFT,       ROTATE LEFT
//!     RIGHT,      ROTATE RIGHT
//!     STOP,       STOPPED
//!     L_FORWARD,  MOVE LEFT (GOING FORWARD)
//!     R_FORWARD   MOVE RIGHT (GOING FORWARD)
//!     L_BACKWARD  MOVE LEFT (GOING BACKWARD)
//!     R_BACKWARD  MOVE RIGHT (GOING BACKWARD)
//!     LOCK,       LOCKED
//!     NO_SET,     NOT SET
//!
//!****************************************************************************
*/
typedef enum {
                           FORWARD,
                           BACKWARD,
                           LEFT,
                           RIGHT,
                           L_FORWARD,
                           R_FORWARD,
                           L_BACKWARD,
                           R_BACKWARD,
                           STOP,
                           LOCK_FORWARD,
                           NO_SET
             } direction_t;

/******************************************************************************
//!
//! \brief This routine converts a direction in a string
//!
//! \param  direction, a direction value to convert
//! \param  string, a string where to set the result
//!
//! \return none
//!
//!*****************************************************************************
*/
void roverDirectionGetDirectionString(direction_t direction, char *string);

/******************************************************************************
//!
//! \brief This routine converts a string in a direction enum
//!
//! \param  direction, a pointer to a direction variable where set the value
//! \param  string, a string to converts
//!
//! \return none
//!
//!*****************************************************************************
*/

void roverDirectionSetDirectionFromString(direction_t *direction, char *string);




#endif /* TDA_ROVERDIRECTION_H_ */
