/*
 * rovermode.h
 *  TAD rover mode structure
 *      mode rover mode of work (0 INTERACTIVE/1 LOOP)
 *      loops number of loops to execute when mode is lopp
 *
 *  Created on: 3 jun. 2018
 *      Author: antonio
 */

#ifndef TDA_ROVERMODE_H_
#define TDA_ROVERMODE_H_

/* RTOS header files */
#include "FreeRTOS.h"


/******************************************************************************
//!
//! Define the rover mode structure
//!
//!*****************************************************************************
 */

typedef struct {
                uint8_t mode;
                uint8_t loops;
} t_Mode;

/******************************************************************************
//
//! \brief The Function initialize a rover move structure
//!
//! \param   xRoverMode, pointer to a rover mode structure to initialize
//!
//! \return None
//!
//!*****************************************************************************
 */
void vRoverModeInit(t_Mode *xRoverMode);

/******************************************************************************
//
//! \brief This routine sets number of loops
//!
//! \param  loops, number of loops to set
//! \param  pRoverMode, pointer to a rover mode structure
//!
//! \return None
//!
//!*****************************************************************************
 */
void vRoverModeSetLoop(uint8_t loops, t_Mode *pRoverMode);

/******************************************************************************
//
//! \brief The routine get number of loops
//!
//! \param   mode, rover mode structure with the data
//!
//! \return  uint8_t, number of loops configured
//!
//!*****************************************************************************
*/
uint8_t ucRoverModeGetLoop(t_Mode roverMode);

/******************************************************************************
//
//! \brief This routine set the mode in rover mode structure
//!
//! \param  mode,   mode to set
//! \param  pRoverMode, a pointer to rover mode structure with the data
//!
//! \return None
//!
//!*****************************************************************************
*/
void vRoverModeSetMode(uint8_t mode, t_Mode *pRoverMode);

/******************************************************************************
//
//! \brief The Function gets the mode from rover mode structure
//!
//! \param  roverMode, a rover mode structure with data
//!
//! \return uint8_t,    the mode configured
//!
//!*****************************************************************************
*/
uint8_t ucRoverModeGetMode(t_Mode roverMode);

/******************************************************************************
//
//! \brief  This routine will indicate if rover structure is complete
//!
//! \param   mode, a rover mode structure
//!
//! \return uint8_t pdTRUE if structure is complete
//!                 pdFASLE if structure is not ready
//!
//!*****************************************************************************
*/
uint8_t ucRoverModeReady(t_Mode roverMode);

#endif /* TDA_ROVERMODE_H_ */
