/*
 * tmpsensor.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */


/*
 * telemetry.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */

#include <Queues/queuedebug.h>

/* Standard Include */
#include <stdio.h>

#include <ti/drivers/I2C.h>
/* Module Header */
#include <ti/sail/bme280/bme280.h>

#include <Board.h>

struct bme280_t bme280;

#define MAX_STRING          (100)

extern s32 bme280_data_readout_template(I2C_Handle i2cHndl);


//!****************************************************************************
//!
//! \brief              This routine initializes BME280 driver
//!
//! \param  i2cHandle,  a pointer to i2cHandle
//!
//! \return none
//!
//*****************************************************************************

void bme280sensorsInit(I2C_Handle i2cHndl){

    uint8_t retc;

    /* Use readout template for read sensor values */
    retc = bme280_data_readout_template(i2cHndl);
    /* Initialize the BME Sensor */
    if(BME280_INIT_VALUE != retc)
    {
        xQueueDebugSend("[BME280] Error Initializing bme280\n");
    }
    bme280_set_power_mode(BME280_NORMAL_MODE);


}

//!****************************************************************************
//!
//! \brief              This routine get parameters from BME280 sensor
//!
//! \param  i2c,    a pointer to i2cHandle
//! \param  press,  a pointer to char for keeping pressure from BME280 sensor
//! \param  temp,   a pointer to char for keeping temperature from BME280 sensor
//! \param  hum,    a pointer to char for keeping humidity from BME280 sensor
//!
//! \return none
//!
//*****************************************************************************
void bme280sensorsGetParams(I2C_Handle i2cHandle,char *press,char *temp,char *hum){

    s32    g_s32ActualTemp   = 0;
    u32    g_u32ActualPress  = 0;
    u32    g_u32ActualHumity = 0;

    /* Read BME280 sensor parameters */
    if(BME280_INIT_VALUE == bme280_read_pressure_temperature_humidity(&g_u32ActualPress,
                           &g_s32ActualTemp, &g_u32ActualHumity))
    {
        /* Convert read values in strings */
        sprintf(press,"%u",g_u32ActualPress/100);
        sprintf(temp,"%u",g_s32ActualTemp/100); /* to compensate error */
        sprintf(hum,"%u",g_u32ActualHumity/1000);
    }
    else
    {
        xQueueDebugSend("[TELEMETRY] Error reading from the bme280 sensor");
    }

}


