/*
 * bmi160sensors.c
 *
 *  Created on: 13 may. 2018
 *      Author: antonio
 */



#include "bmi160sensors.h"

/* Module Header */
#include <ti/sail/bmi160/bmi160.h>

/* Example Header file */
#include "bmi160_support.h"

/* Example/Board Header files */
#include "Board.h"

#include <stdio.h>

#include "telemetry.h"

#include "common_def.h"

//!****************************************************************************
//!
//! \brief              This routine initializes BMI160 driver
//!
//! \param  i2cHandle,  a pointer to i2cHandle
//!
//! \return none
//!
//*****************************************************************************

void bmi160sensorsInit(I2C_Handle i2cHndl){
    configASSERT_ON_ERROR(bmi160_initialize_sensor(i2cHndl));
}

//!****************************************************************************
//!
//! \brief              This routine initializes BMI160 driver
//!
//! \param  i2c,    a pointer to i2cHandle
//! \param  acce,   a pointer to t_Acce structure where routine will set accelerometer values
//! \param  gyro,   a pointer to t_Gyro structure where routine will set gyroscope values
//! \param  mag,    a pointer to t_Mag structure where routine will set compass values
//!
//! \return none
//!
//*****************************************************************************
void bmi160sensorsGetParams(I2C_Handle i2c, t_Acce *acce, t_Gyro *gyro , t_Mag *mag ){

    int8_t com_rslt;

    struct bmi160_gyro_t gyroxyz = {0,0,0};
    struct bmi160_accel_t accelxyz = {0,0,0};
    struct bmi160_mag_t magxyz = {0,0,0};

    /* read gyroscope values */
    com_rslt = bmi160_read_gyro_xyz(&gyroxyz);
    configASSERT_ON_ERROR(com_rslt);

    /* read accelerometer values */
    com_rslt = bmi160_read_accel_xyz(&accelxyz);
    configASSERT_ON_ERROR(com_rslt);

    /* read magnetic field values */
    com_rslt = bmi160_read_mag_xyz(&magxyz, 0);
    configASSERT_ON_ERROR(com_rslt);

    /* convert values in strings and set in each structure */

    sprintf(mag->bmi160mag_x,"%d",magxyz.x);
    sprintf(mag->bmi160mag_y,"%d",magxyz.y);
    sprintf(mag->bmi160mag_z,"%d",magxyz.z);

    sprintf(gyro->bmi160gyro_x,"%d",gyroxyz.x);
    sprintf(gyro->bmi160gyro_y,"%d",gyroxyz.y);
    sprintf(gyro->bmi160gyro_z,"%d",gyroxyz.z);

    sprintf(acce->bmi160acce_x,"%d", accelxyz.x);
    sprintf(acce->bmi160acce_y,"%d", accelxyz.y);
    sprintf(acce->bmi160acce_z,"%d", accelxyz.z);

}
