/*
 * tmpsensor.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */


/*
 * telemetry.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */

#include <Queues/queuedebug.h>

#include <stdint.h>
#include <stddef.h>
#include <unistd.h>

/* Standard Include */
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include <ti/drivers/I2C.h>
/* Module Header */
#include <ti/sail/opt3001/opt3001.h>

#include <Board.h>



#define MAX_STRING          (100)

//!****************************************************************************
//!
//! \brief              This routine initialize OPT3001 sensor driver
//!
//! \param  none
//!
//! \return none
//!
//*****************************************************************************
void optsensorInit(){
    // Init opt sensor

    OPT3001_init();
}

//!****************************************************************************
//!
//! \brief              This routine get a measurement of ambient light
//!                     from OPT3001 optical sensor
//!
//! \param  i2cHandle,  a pointer to i2cHandle to use
//! \param  lux,        a pointer to chart structure (string) where ambient light
//!                     value in lux will be set
//!
//! \return none
//!
//*****************************************************************************
void optsensorGetLux(I2C_Handle i2cHandle,char *strLux){

    float lux;

    OPT3001_Handle opt3001Handle;
    OPT3001_Params opt3001Params;

    /* Open OPT3001 sensor with custom parameters */
     opt3001Handle = OPT3001_open(Board_OPT3001_LIGHT, i2cHandle,
             NULL);

     /* Check if the open is successful */
     if(opt3001Handle == NULL) {
         xQueueDebugSend("[TELEMETRY] OPT3001 Open Failed!");
         while(1);
     }

    /* Initialize opt3001Params structure to defaults */
    OPT3001_Params_init(&opt3001Params);

    /* Get current Lux */
    if (!OPT3001_getLux(opt3001Handle, &lux)) {
        xQueueDebugSend("[TELEMETRY] OPT3001 sensor read failed");
    }
    sprintf(strLux,"%f",lux);

    OPT3001_close(opt3001Handle);

}
