/*
 * telemetry.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */

#include "telemetry.h"

#include <stdint.h>
#include <string.h>

//*****************************************************************************
//
//! \brief Initialize telemetry structure
//!
//! \param  pTelemetry pointer to a telemetry structure to fill in
//!
//! \return none
//!
//*****************************************************************************
void telemetryInit(t_Telemetry *telemetry){
    strcpy(telemetry->temp,"00");
    strcpy(telemetry->lux,"00");
    strcpy(telemetry->acc.bmi160acce_x,"00");
    strcpy(telemetry->acc.bmi160acce_y,"00");
    strcpy(telemetry->acc.bmi160acce_z,"00");
    strcpy(telemetry->gyr.bmi160gyro_x,"00");
    strcpy(telemetry->gyr.bmi160gyro_y,"00");
    strcpy(telemetry->gyr.bmi160gyro_z,"00");
    strcpy(telemetry->mag.bmi160mag_x,"00");
    strcpy(telemetry->mag.bmi160mag_y,"00");
    strcpy(telemetry->mag.bmi160mag_z,"00");
    strcpy(telemetry->bme.bme280hum,"00");
    strcpy(telemetry->bme.bme280pre,"00");
    strcpy(telemetry->bme.bme280tmp,"00");
    strcpy(telemetry->rStatus.direction,"STOP");
    strcpy(telemetry->rStatus.speed,"5");

}

//*****************************************************************************
//
//! \brief Set temperature in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  temperature, string with temperature value
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetTemperature(t_Telemetry *telemetry,char *temperature){

    strcpy(telemetry->temp,temperature);
  }


//*****************************************************************************
//
//! \brief Get temperature from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  temperature, a string where routine will fill in with temperature value
//!
//! \return lenght of temperature string
//!
//*****************************************************************************
uint8_t telemetryGetTemperatureStr(t_Telemetry telemetry, char *temperature){

    strcpy(temperature,telemetry.temp);
    return strlen(telemetry.temp);
}

//*****************************************************************************
//
//! \brief Get lux from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  lux, a string where routine will fill in with lux value
//!
//! \return lenght of temperature string
//!
//*****************************************************************************
uint8_t telemetryGetLuxStr(t_Telemetry telemetry,char *lux){
    strcpy(lux,telemetry.lux);
    return strlen(telemetry.lux);
}

//*****************************************************************************
//
//! \brief Get BME280 sensor humidity from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  hum, a string where routine will fill in with humidity value
//!
//! \return lenght of humidity string
//!
//*****************************************************************************
uint8_t telemetryGetBme280HumStr(t_Telemetry telemetry,char *hum){
    strcpy(hum,telemetry.bme.bme280hum);
    return strlen(telemetry.bme.bme280hum);
}

//*****************************************************************************
//
//! \brief Get BME280 pressure sensor from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  pre, a string where routine will fill in with pressure value
//!
//! \return lenght of humidity string
//!
//*****************************************************************************
uint8_t telemetryGetBme280PreStr(t_Telemetry telemetry,char *pre){
    strcpy(pre,telemetry.bme.bme280pre);
    return strlen(telemetry.bme.bme280pre);
}

//*****************************************************************************
//
//! \brief Get BME280 temperature sensor from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  temp, a string where routine will fill in with temperature value
//!
//! \return length of temperature string
//!
//*****************************************************************************
uint8_t telemetryGetBme280TemStr(t_Telemetry telemetry,char *tem){
    strcpy(tem,telemetry.bme.bme280tmp);
    return strlen(telemetry.bme.bme280tmp);
}

//*****************************************************************************
//
//! \brief Set lux value in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  lux, string with lux value
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetLux(t_Telemetry *telemetry,char *lux){
    strcpy(telemetry->lux,lux);
}
void telemetryGetLux(t_Telemetry *telemetry,char *lux){

    strcpy(lux,telemetry->lux);
}

//*****************************************************************************
//
//! \brief Get enviroment telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all enviroment telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryEnvToString(t_Telemetry telemetry,char *string){
    strcpy(string,"Temp=");
    strcat(string,telemetry.temp);
    strcat(string,",Lux=");
    strcat(string,telemetry.lux);
    strcat(string,",BME280_tem=");
    strcat(string,telemetry.bme.bme280tmp);
    strcat(string,",BME280_hum=");
    strcat(string,telemetry.bme.bme280hum);
    strcat(string,",BME280_pres=");
    strcat(string,telemetry.bme.bme280pre);
}

//*****************************************************************************
//
//! \brief Get compass telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all compass telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryMagToString(t_Telemetry telemetry,char *string){
    strcat(string,"MAG_X=");
    strcat(string,telemetry.mag.bmi160mag_x);
    strcat(string,",MAG_Y=");
    strcat(string,telemetry.mag.bmi160mag_y);
    strcat(string,",MAG_Z=");
    strcat(string,telemetry.mag.bmi160mag_z);
}

//*****************************************************************************
//
//! \brief Get gyroscope telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all gyroscpe telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryGyroToString(t_Telemetry telemetry,char *string){
    strcat(string,"GYRO_X=");
    strcat(string,telemetry.gyr.bmi160gyro_x);
    strcat(string,",GYRO_Y=");
    strcat(string,telemetry.gyr.bmi160gyro_y);
    strcat(string,",GYRO_Z=");
    strcat(string,telemetry.gyr.bmi160gyro_z);
}

//*****************************************************************************
//
//! \brief Get accelerometer telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all accelerometer telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryAcceToString(t_Telemetry telemetry,char *string){
    strcat(string,"ACC_X=");
    strcat(string,telemetry.acc.bmi160acce_x);
    strcat(string,",ACC_Y=");
    strcat(string,telemetry.acc.bmi160acce_y);
    strcat(string,",ACC_Z=");
    strcat(string,telemetry.acc.bmi160acce_z);
}

//*****************************************************************************
//
//! \brief Get rover status telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all roverstatus telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryRStatusToString(t_Telemetry telemetry,char *string){
    strcat(string, "R_Direction=");
    strcat(string, telemetry.rStatus.direction);
    strcat(string,",R_Speed=");
    strcat(string,telemetry.rStatus.speed);

}

//*****************************************************************************
//
//! \brief Get telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryToString(t_Telemetry telemetry,char *string){
    strcpy(string,"Temp=");
    strcat(string,telemetry.temp);
    strcat(string,",Lux=");
    strcat(string,telemetry.lux);
    strcat(string,",BME280_tem=");
    strcat(string,telemetry.bme.bme280tmp);
    strcat(string,",BME280_hum=");
    strcat(string,telemetry.bme.bme280hum);
    strcat(string,",BME280_pres=");
    strcat(string,telemetry.bme.bme280pre);
    strcat(string,",MAG_X=");
    strcat(string,telemetry.mag.bmi160mag_x);
    strcat(string,",MAG_Y=");
    strcat(string,telemetry.mag.bmi160mag_y);
    strcat(string,",MAG_Z=");
    strcat(string,telemetry.mag.bmi160mag_z);
    strcat(string,",ACC_X=");
    strcat(string,telemetry.acc.bmi160acce_x);
    strcat(string,",ACC_Y=");
    strcat(string,telemetry.acc.bmi160acce_y);
    strcat(string,",ACC_Z=");
    strcat(string,telemetry.acc.bmi160acce_z);
    strcat(string,",GYRO_X=");
    strcat(string,telemetry.gyr.bmi160gyro_x);
    strcat(string,",GYRO_Y=");
    strcat(string,telemetry.gyr.bmi160gyro_y);
    strcat(string,",GYRO_Z=");
    strcat(string,telemetry.gyr.bmi160gyro_z);
    strcat(string,",R_Direction=");
    strcat(string,telemetry.rStatus.direction);
    strcat(string,",R_Speed=");
    strcat(string,telemetry.rStatus.speed);

}

//*****************************************************************************
//
//! \brief Compare two telemetry structures
//!
//! \param  telemetry1, a telemetry structure
//! \param  telemetry2, a telemetry structure
//!
//! \return zero if they are equal and other values if they are different
//!
//*****************************************************************************
uint8_t telemetrycmp(t_Telemetry telemetry1, t_Telemetry telemetry2){

    uint8_t result;
    result = strcmp(telemetry1.lux, telemetry2.lux);
    result += strcmp(telemetry1.temp, telemetry2.temp);
    result += strcmp(telemetry1.bme.bme280pre, telemetry2.bme.bme280pre);
    result += strcmp(telemetry1.bme.bme280hum, telemetry2.bme.bme280hum);
    result += strcmp(telemetry1.bme.bme280tmp, telemetry2.bme.bme280tmp);
    result += strcmp(telemetry1.acc.bmi160acce_x, telemetry2.acc.bmi160acce_x);
    result += strcmp(telemetry1.acc.bmi160acce_y, telemetry2.acc.bmi160acce_y);
    result += strcmp(telemetry1.acc.bmi160acce_z, telemetry2.acc.bmi160acce_z);
    result += strcmp(telemetry1.gyr.bmi160gyro_x, telemetry2.gyr.bmi160gyro_x);
    result += strcmp(telemetry1.gyr.bmi160gyro_y, telemetry2.gyr.bmi160gyro_y);
    result += strcmp(telemetry1.gyr.bmi160gyro_z, telemetry2.gyr.bmi160gyro_z);
    result += strcmp(telemetry1.mag.bmi160mag_x, telemetry2.mag.bmi160mag_x);
    result += strcmp(telemetry1.mag.bmi160mag_y, telemetry2.mag.bmi160mag_y);
    result += strcmp(telemetry1.mag.bmi160mag_z, telemetry2.mag.bmi160mag_z);
    result += strcmp(telemetry1.rStatus.direction, telemetry2.rStatus.direction);
    result += strcmp(telemetry1.rStatus.speed, telemetry2.rStatus.speed);

    return result;

}

//*****************************************************************************
//
//! \brief Copy a telemetry structure in another telemetry structure
//!
//! \param  telemetry1, a telemetry structure
//! \param  telemetry2, a telemetry structure
//!
//! \return none
//!
//*****************************************************************************
void telemetrycpy(t_Telemetry *telemetry1, t_Telemetry *telemetry2){


    strcpy(telemetry1->lux, telemetry2->lux);
    strcpy(telemetry1->temp,telemetry2->temp);
    strcpy(telemetry1->bme.bme280pre, telemetry2->bme.bme280pre);
    strcpy(telemetry1->bme.bme280hum, telemetry2->bme.bme280hum);
    strcpy(telemetry1->bme.bme280tmp, telemetry2->bme.bme280tmp);
    strcpy(telemetry1->acc.bmi160acce_x, telemetry2->acc.bmi160acce_x);
    strcpy(telemetry1->acc.bmi160acce_y, telemetry2->acc.bmi160acce_y);
    strcpy(telemetry1->acc.bmi160acce_z, telemetry2->acc.bmi160acce_z);
    strcpy(telemetry1->gyr.bmi160gyro_x, telemetry2->gyr.bmi160gyro_x);
    strcpy(telemetry1->gyr.bmi160gyro_y, telemetry2->gyr.bmi160gyro_y);
    strcpy(telemetry1->gyr.bmi160gyro_z, telemetry2->gyr.bmi160gyro_z);
    strcpy(telemetry1->mag.bmi160mag_x, telemetry2->mag.bmi160mag_x);
    strcpy(telemetry1->mag.bmi160mag_y, telemetry2->mag.bmi160mag_y);
    strcpy(telemetry1->mag.bmi160mag_z, telemetry2->mag.bmi160mag_z);
    strcpy(telemetry1->rStatus.direction, telemetry2->rStatus.direction);
    strcpy(telemetry1->rStatus.speed, telemetry2->rStatus.speed);


}

//*****************************************************************************
//
//! \brief Set BME280 sensors value in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  bme, t_Bme280 with BME280 sensors value
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetBme280(t_Telemetry *telemetry, t_Bme280 bme){
    strcpy(telemetry->bme.bme280hum,bme.bme280hum);
    strcpy(telemetry->bme.bme280pre,bme.bme280pre);
    strcpy(telemetry->bme.bme280tmp,bme.bme280tmp);
}

//*****************************************************************************
//
//! \brief Get BME280 sensors value from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  bme, a t_Bme280 structure where routine will fill in with Bme280 sensor values
//!
//! \return none
//!
//*****************************************************************************
void telemetryGetBme280(t_Telemetry telemetry, t_Bme280 bme){
    strcpy(bme.bme280hum,telemetry.bme.bme280hum);
    strcpy(bme.bme280pre,telemetry.bme.bme280pre);
    strcpy(bme.bme280tmp,telemetry.bme.bme280tmp);
}

//*****************************************************************************
//
//! \brief Set BMI160 compass values in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  mag, a t_Mag structure with BMI160 compass values
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetBmi160Mag(t_Telemetry *telemetry, t_Mag mag){
    strcpy(telemetry->mag.bmi160mag_x, mag.bmi160mag_x);
    strcpy(telemetry->mag.bmi160mag_y, mag.bmi160mag_y);
    strcpy(telemetry->mag.bmi160mag_z, mag.bmi160mag_z);
}

//*****************************************************************************
//
//! \brief Get BMI160 compass values from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  mag, a t_mag structure where routine will fill in with compass values
//!
//! \return none
//!
//*****************************************************************************
void telemetryGetBmi160Mag(t_Telemetry telemetry, t_Mag mag){
    strcpy(mag.bmi160mag_x,telemetry.mag.bmi160mag_x);
    strcpy(mag.bmi160mag_y,telemetry.mag.bmi160mag_y);
    strcpy(mag.bmi160mag_z,telemetry.mag.bmi160mag_z);
}

//*****************************************************************************
//
//! \brief Set BMI160 gyroscope values in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  gyr, a t_Mag structure with BMI160 gyroscope values
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetBmi160Gyro(t_Telemetry *telemetry, t_Gyro gyr){
    strcpy(telemetry->gyr.bmi160gyro_x, gyr.bmi160gyro_x);
    strcpy(telemetry->gyr.bmi160gyro_y, gyr.bmi160gyro_y);
    strcpy(telemetry->gyr.bmi160gyro_z, gyr.bmi160gyro_z);
}

//*****************************************************************************
//
//! \brief Get BMI160 gyroscope values from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  gyr, a t_Gyro structure where routine will fill in with gyroscope values
//!
//! \return none
//!
//*****************************************************************************
void telemetryGetBmi260Gyro(t_Telemetry telemetry, t_Gyro gyr){
    strcpy(gyr.bmi160gyro_x,telemetry.gyr.bmi160gyro_x);
    strcpy(gyr.bmi160gyro_y,telemetry.gyr.bmi160gyro_y);
    strcpy(gyr.bmi160gyro_z,telemetry.gyr.bmi160gyro_z);
}

//*****************************************************************************
//
//! \brief Set BMI160 accelerometer values in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  acce, a t_Mag structure with BMI160 accelerometer values
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetBmi160Accel(t_Telemetry *telemetry, t_Acce acce){
    strcpy(telemetry->acc.bmi160acce_x, acce.bmi160acce_x);
    strcpy(telemetry->acc.bmi160acce_y, acce.bmi160acce_y);
    strcpy(telemetry->acc.bmi160acce_z, acce.bmi160acce_z);
}

//*****************************************************************************
//
//! \brief Get BMI160 accelerometer values from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  acce, a t_Acce structure where routine will fill in with accelerometer values
//!
//! \return none
//!
//*****************************************************************************
void telemetryGetBmi260Accel(t_Telemetry telemetry, t_Acce acce){
    strcpy(acce.bmi160acce_x, telemetry.acc.bmi160acce_x);
    strcpy(acce.bmi160acce_y, telemetry.acc.bmi160acce_y);
    strcpy(acce.bmi160acce_z, telemetry.acc.bmi160acce_z);

}




