/*
 * telemetry.h
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */

#ifndef TELEMETRY_TELEMETRY_H_
#define TELEMETRY_TELEMETRY_H_

#include "common_def.h"
#include <stdint.h>

/* Structures for keep telemetry dates */

typedef struct {
    char bmi160gyro_x[MAX_STRING_PARAM];
    char bmi160gyro_y[MAX_STRING_PARAM];
    char bmi160gyro_z[MAX_STRING_PARAM];

} t_Gyro;

typedef struct {
    char bmi160acce_x[MAX_STRING_PARAM];
    char bmi160acce_y[MAX_STRING_PARAM];
    char bmi160acce_z[MAX_STRING_PARAM];

} t_Acce;

typedef struct {
    char bmi160mag_x[MAX_STRING_PARAM];
    char bmi160mag_y[MAX_STRING_PARAM];
    char bmi160mag_z[MAX_STRING_PARAM];
} t_Mag;

typedef struct {
    char bme280tmp[MAX_STRING_PARAM];
    char bme280pre[MAX_STRING_PARAM];
    char bme280hum[MAX_STRING_PARAM];
} t_Bme280;

typedef struct {
    char speed[MAX_STRING_PARAM];
    char direction[MAX_STRING];
} t_rStatus;


typedef struct {
                char temp[MAX_STRING_PARAM];
                char lux[MAX_STRING_PARAM];
                t_rStatus rStatus;
                t_Bme280 bme;
                t_Mag mag;
                t_Acce acc;
                t_Gyro gyr;

} t_Telemetry;

//*****************************************************************************
//
//! \brief Initialize telemetry structure
//!
//! \param [IN|OUT]  pTelemetry pointer to a telemetry structure to fill in
//!
//! \return none
//!
//*****************************************************************************

void telemetryInit(t_Telemetry *pTelemetry);

//*****************************************************************************
//
//! \brief Set temperature in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param [IN|OUT] temperature, string with temperature value
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetTemperature(t_Telemetry *pTelemetry,char *temperature);

//*****************************************************************************
//
//! \brief Get temperature from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param [IN|OUT] temperature, a string where routine will fill in with temperature value
//!
//! \return lenght of temperature string
//!
//*****************************************************************************

uint8_t telemetryGetTemperatureStr(t_Telemetry telemetry, char *temperature);

//*****************************************************************************
//
//! \brief Set lux value in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param [IN|OUT] lux, string with lux value
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetLux(t_Telemetry *telemetry,char *lux);

//*****************************************************************************
//
//! \brief Get lux from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param [IN|OUT] lux, a string where routine will fill in with lux value
//!
//! \return lenght of temperature string
//!
//*****************************************************************************
uint8_t telemetryGetLuxStr(t_Telemetry telemetry,char *lux);

//*****************************************************************************
//
//! \brief Set BME280 sensors value in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param [IN|OUT] bme, t_Bme280 with BME280 sensors value
//!
//! \return none
//!
//*****************************************************************************

void telemetrySetBme280(t_Telemetry *telemetry, t_Bme280 bme);


void telemetryGetBme280(t_Telemetry telemetry, t_Bme280 bme);

//*****************************************************************************
//
//! \brief Get BME280 sensor humidity from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  hum, a string where routine will fill in with humidity value
//!
//! \return lenght of humidity string
//!
//*****************************************************************************

uint8_t telemetryGetBme280HumStr(t_Telemetry telemetry,char *hum);

//*****************************************************************************
//
//! \brief Get BME280 pressure sensor from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  pre, a string where routine will fill in with pressure value
//!
//! \return lenght of humidity string
//!
//*****************************************************************************
uint8_t telemetryGetBme280PreStr(t_Telemetry telemetry,char *pre);

//*****************************************************************************
//
//! \brief Get BME280 temperature sensor from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  temp, a string where routine will fill in with temperature value
//!
//! \return length of temperature string
//!
//*****************************************************************************
uint8_t telemetryGetBme280TemStr(t_Telemetry telemetry,char *temp);

//*****************************************************************************
//
//! \brief Set BMI160 compass values in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  mag, a t_Mag structure with BMI160 compass values
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetBmi160Mag(t_Telemetry *telemetry, t_Mag mag);

//*****************************************************************************
//
//! \brief Get BMI160 compass values from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  mag, a t_mag structure where routine will fill in with compass values
//!
//! \return none
//!
//*****************************************************************************
void telemetryGetBmi160Mag(t_Telemetry telemetry, t_Mag mag);

//*****************************************************************************
//
//! \brief Set BMI160 gyroscope values in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  gyr, a t_Mag structure with BMI160 gyroscope values
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetBmi160Gyro(t_Telemetry *telemetry, t_Gyro gyr);

//*****************************************************************************
//
//! \brief Get BMI160 gyroscope values from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  gyr, a t_Gyro structure where routine will fill in with gyroscope values
//!
//! \return none
//!
//*****************************************************************************
void telemetryGetBmi260Gyro(t_Telemetry telemetry, t_Gyro gyr);

//*****************************************************************************
//
//! \brief Set BMI160 accelerometer values in a telemetry structure
//!
//! \param  pTelemetry, pointer to a telemetry structure to fill in
//! \param  acce, a t_Mag structure with BMI160 accelerometer values
//!
//! \return none
//!
//*****************************************************************************
void telemetrySetBmi160Accel(t_Telemetry *telemetry, t_Acce acce);

//*****************************************************************************
//
//! \brief Get BMI160 accelerometer values from a telemetry structure
//!
//! \param  telemetry, a telemetry structure
//! \param  acce, a t_Acce structure where routine will fill in with accelerometer values
//!
//! \return none
//!
//*****************************************************************************
void telemetryGetBmi260Accel(t_Telemetry telemetry, t_Acce acce);

//*****************************************************************************
//
//! \brief Get telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryToString(t_Telemetry telemetry, char *string);

//*****************************************************************************
//
//! \brief Get enviroment telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all enviroment telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryEnvToString(t_Telemetry telemetry,char *string);

//*****************************************************************************
//
//! \brief Get compass telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all compass telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryMagToString(t_Telemetry telemetry,char *string);

//*****************************************************************************
//
//! \brief Get gyroscope telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all gyroscpe telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryGyroToString(t_Telemetry telemetry,char *string);

//*****************************************************************************
//
//! \brief Get accelerometer telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all accelerometer telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryAcceToString(t_Telemetry telemetry,char *string);

//*****************************************************************************
//
//! \brief Get rover status telemetry in a string
//!
//! \param  telemetry, a telemetry structure
//! \param  string, a string with all roverstatus telemetry values join together
//!
//! \return none
//!
//*****************************************************************************
void telemetryRStatusToString(t_Telemetry telemetry,char *string);

//*****************************************************************************
//
//! \brief Compare two telemetry structures
//!
//! \param  telemetry1, a telemetry structure
//! \param  telemetry2, a telemetry structure
//!
//! \return zero if they are equal and other values if they are different
//!
//*****************************************************************************

uint8_t telemetrycmp(t_Telemetry telemetry1, t_Telemetry telemetry2);

//*****************************************************************************
//
//! \brief Copy a telemetry structure in another telemetry structure
//!
//! \param  telemetry1, a telemetry structure
//! \param  telemetry2, a telemetry structure
//!
//! \return none
//!
//*****************************************************************************

void telemetrycpy(t_Telemetry *telemetry1, t_Telemetry *telemetry2);


#endif /* TELEMETRY_TELEMETRY_H_ */
