/*
 * telemetry.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */

/* Queues in use */
#include <Queues/queuedebug.h>
#include <Queues/queuetelemetry.h>

#include <Telemetry/tmpsensor.h>
#include <Telemetry/optsensor.h>
#include <Telemetry/bme280sensors.h>
#include <Telemetry/bmi160sensors.h>
#include <Telemetry/telemetry.h>
#include <Watchdog/watchdog.h>

/* Module Header */
#include <ti/sail/opt3001/opt3001.h>
#include <ti/sail/tmp007/tmp007.h>

#include <stdint.h>
#include <stddef.h>
#include <unistd.h>

/* Standard Include */
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include <ti/drivers/I2C.h>

#include <Board.h>

void *telemetryTask(void *arg){

    I2C_Handle      i2c;
    I2C_Params      i2cParams;

    t_Telemetry telemetry;

    xQueueDebugSend("[TELEMETRY TASK]] Starting telemetry task");

    /* Initialize I2C bus */
    I2C_init();

    xQueueDebugSend("[TELEMETRY TASK]] Init I2C");

    /* Create I2C for usage */
    I2C_Params_init(&i2cParams);
    i2cParams.bitRate = I2C_400kHz;
    i2c = I2C_open(Board_I2C_TMP, &i2cParams);
    configASSERT(i2c);

    xQueueDebugSend("[TELEMETRY TASK]] I2C Bus initialized!");


    /* Init sensors */
    tmpsensorInit();
    optsensorInit();
    bme280sensorsInit(i2c);
    bmi160sensorsInit(i2c);

    /* Init telemetry structure */
    telemetryInit(&telemetry);

    xQueueDebugSend("[TELEMETRY TASK] Telemetry sensors initiated");

    while(1){

        /* Everything is going OK, clear the watch dog */
        watchdogReset();

       /* Get temperature */
        tmpsensorGetTemperature(i2c, telemetry.temp);

        /* Get light */
        optsensorGetLux(i2c, telemetry.lux);

        /* Get BME280 params */
        bme280sensorsGetParams(i2c, telemetry.bme.bme280pre, telemetry.bme.bme280tmp, telemetry.bme.bme280hum);

        /* Get BMI160 params */
        bmi160sensorsGetParams(i2c, &telemetry.acc, &telemetry.gyr, &telemetry.mag);

        /* Set telemetry to the telemetry queue */
        xQueueTelemetrySet(&telemetry);

        vTaskDelay(pdMS_TO_TICKS( 1000 ));
    }

}
