/*
 * tmpsensor.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */


/*
 * telemetry.c
 *
 *  Created on: 21 abr. 2018
 *      Author: antonio
 */

#include <Queues/queuedebug.h>

#include <stdint.h>
#include <stddef.h>
#include <unistd.h>

/* Standard Include */
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include <ti/drivers/I2C.h>
#include <ti/sail/tmp007/tmp007.h>

#include <Board.h>

#define TMP007_DIE_TEMP     0x0001  /* Die Temp Result Register */
#define TMP007_OBJ_TEMP     0x0003  /* Object Temp Result Register */
#define MAX_STRING          (100)

//!****************************************************************************
//!
//! \brief              This routine initialize TMP701 driver
//!
//! \param  none
//!
//! \return none
//!
//*****************************************************************************
void tmpsensorInit(void){
    TMP007_init();
}

//!*****************************************************************************
//!
//! \brief              This routine gets temperature from TMP701 sensor
//!
//! \param  i2cHandle,  pointer to a telemetry structure to fill in
//! \param  tmp         pointer a string to save temperature from TMP701
//!                     infrared sensor
//!
//! \return none
//!
//*****************************************************************************
void tmpsensorGetTemperature(I2C_Handle i2cHandle,char *tmp){
    float temp;
    TMP007_Handle  tmp007Handle = NULL;
    TMP007_Params  tmp007Params;

    /* Initialize tmp007Params structure to defaults */
    TMP007_Params_init(&tmp007Params);

    /* Set the conversions, affects conversion time */
    tmp007Params.conversions = TMP007_4CONV;

    /* Open TMP007 sensor with custom Params */
    tmp007Handle = TMP007_open(Board_TMP007_ROOMTEMP, i2cHandle,
            &tmp007Params);

    /* Check if the open is successful */
    if (tmp007Handle == NULL) {
        xQueueDebugSend("TMP007_ROOMTEMP0 Open Failed");
        while(1);
    }

    /* Allow the sensor hardware to complete its first conversion */
    sleep(2);

    /* Get Die and Object Temperatures */
    if (!TMP007_getObjTemp(tmp007Handle, TMP007_CELSIUS, &temp)) {
        xQueueDebugSend("TMP007 sensor read failed");

    }
    sprintf(tmp,"%f",temp);

    TMP007_close(tmp007Handle);


}
