/*
 * watchdog.c
 *
 *  Created on: 25 may. 2018
 *      Author: antonio
 */


#include <FreeRTOS.h>
#include <task.h>


/* TI drivers */
#include <ti/drivers/Watchdog.h>

#include "Board.h"

#include <Queues/queuedebug.h>
#include <Watchdog/watchdog.h>


Watchdog_Handle watchdogHandle;


//*************************************************************************
//!
//! \brief watchdogGetHandler
//!
//!
//! \param  unused
//!
//! \return Watchdog_Handle,
//!
//*************************************************************************
Watchdog_Handle watchdogGetHandler(){
    return watchdogHandle;
}

//*************************************************************************
//!
//! \brief watchdogCallback
//!
//!
//! \param  unused
//!
//! \return none
//!
//*************************************************************************

void watchdogCallback(uintptr_t unused)
{
    xQueueDebugSendFromISR("[WATCHDOG TASK] Something is going wrong...");
    /* Clear watchdog interrupt flag */
    Watchdog_clear(watchdogHandle);

}

//*************************************************************************
//!
//! \brief watchdogtask, this routine clear the watch dog
//!
//!
//! \param  Watchdog_Handle, reference to the wdg to clear
//!
//! \return retc, zero if watch dog is clear and -1 in other cases
//!
//*************************************************************************

int8_t watchdogReset(){
    int8_t retc;
    if (watchdogHandle != NULL){
        Watchdog_clear(watchdogHandle);
        retc = 0;
        }
    else {
        retc = -1;
    }
    return retc;
}

//*************************************************************************
//!
//! \brief watchdogtask, this task is resposible of manage system watchdog
//!
//!
//! \param  arg, pointer to task arguments
//!
//! \return none
//!
//*************************************************************************

void *watchdogTask(void *arg){

    Watchdog_Params params;

    Watchdog_init();

    /* Create and enable a watch dog with resets disabled */
    Watchdog_Params_init(&params);

    /* For testing */
    params.resetMode = Watchdog_RESET_OFF;
    params.callbackFxn = (Watchdog_Callback) watchdogCallback;


    /* For production */
    //params.resetMode = Watchdog_RESET_ON ;
    //params.debugStallMode = Watchdog_DEBUG_STALL_ON;
    //params.callbackFxn = NULL ;

    xQueueDebugSend("[WATCHDOG TASK] It will initialize WDG task");

    watchdogHandle = Watchdog_open(Board_WATCHDOG0, &params);
    if (watchdogHandle == NULL) {
        /* Error opening watch dog */
        xQueueDebugSend("[WATCHDOG TASK] Error opening WDG");
        while (1);

    }
    /* Main loop */
    while (1){

        /* Set watch dog reload time */
        Watchdog_setReload(watchdogHandle, Watchdog_convertMsToTicks(watchdogHandle,2000));
        vTaskDelay(pdMS_TO_TICKS( 2000 ));
    }
}





